@@ -114,9 +114,7 @@ lint_r <- function(paths = NULL) {
 }
 
 rhino_style <- function() {
-  style <- styler::tidyverse_style()
-  style$space$style_space_around_math_token <- NULL
-  style
+  styler::tidyverse_style(math_token_spacing = styler::specify_math_token_spacing(zero = "'/'"))
 }
 
 #' Format R
@@ -291,7 +289,8 @@ build_sass_r <- function() {
   sass::sass(
     input = sass::sass_file(fs::path("app", "styles", "main.scss")),
     output = fs::path(output_dir, "app.min.css"),
-    cache = FALSE
+    cache = FALSE,
+    options = sass::sass_options(output_style = "compressed")
   )
 }
 
